@@ -24,7 +24,6 @@
 // Qt includes
 
 #include <QIcon>
-#include <kiconloader.h>
 #include <KLocalizedString>
 #include <KGuiItem>
 #include <KStandardGuiItem>
@@ -76,7 +75,7 @@ void DetailDialog::updateDetails()
         return;
     }
 
-    icon->setPixmap(item->logLine()->logLevel()->icon());
+    icon->setPixmap(item->logLine()->logLevel()->icon().pixmap(style()->pixelMetric(QStyle::PM_LargeIconSize)));
 
     header->setText(item->logLine()->formattedText());
 
