@@ -21,25 +21,23 @@
 
 #include "globals.h"
 
-#include <QString>
-#include <QList>
 #include <QMap>
 
 #include <KLocalizedString>
 
 #include "defaults.h"
 #include "logLevel.h"
-#include "logMode.h"
 #include "logFile.h"
 
 #include "analyzer.h"
 #include "logModeAction.h"
-#include "logModeFactory.h"
 #include "logModeConfiguration.h"
 #include "logModeConfigurationWidget.h"
 
 #include "logging.h"
 
+Q_LOGGING_CATEGORY(KSYSTEMLOG, "ksystemlog", QtWarningMsg)
+
 Globals &Globals::instance()
 {
     static Globals self;
