@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _KIO_LOG_FILE_READER_H_
-#define _KIO_LOG_FILE_READER_H_
+#ifndef KIO_LOG_FILE_READER_H
+#define KIO_LOG_FILE_READER_H
 
 #include <QObject>
 #include <QByteArray>
@@ -43,17 +43,17 @@ class KioLogFileReader : public QObject
     Q_OBJECT
 
 public:
-    KioLogFileReader(const LogFile &logFile);
+    explicit KioLogFileReader(const LogFile &logFile);
 
     virtual ~KioLogFileReader();
 
     void open();
     void close();
 
-signals:
+Q_SIGNALS:
     void lineRead(const QString &);
 
-private slots:
+private Q_SLOTS:
     void openDone(KIO::Job *job);
     void closeDone(KIO::Job *job);
     void dataReceived(KIO::Job *job, const QByteArray &data);
@@ -67,4 +67,4 @@ private:
     KioLogFileReaderPrivate *const d;
 };
 
-#endif // _KIO_LOG_FILE_READER_H_
+#endif // _KIO_LOG_FILE_READER_H
