@@ -21,7 +21,6 @@
 
 #include "logLevel.h"
 
-#include <kiconloader.h>
 #include <QIcon>
 class LogLevelPrivate
 {
@@ -29,11 +28,9 @@ public:
     int id;
     QString name;
 
-    QString icon;
-
     QColor color;
 
-    QPixmap pixmap;
+    QIcon icon;
 };
 
 LogLevel::LogLevel(int id, const QString &nm, const QString &ic, const QColor &col, QObject *parent)
@@ -41,9 +38,8 @@ LogLevel::LogLevel(int id, const QString &nm, const QString &ic, const QColor &c
 {
     d->id = id;
     d->name = nm;
-    d->icon = ic;
     d->color = col;
-    d->pixmap = QIcon::fromTheme(ic).pixmap(KIconLoader::SizeSmall);
+    d->icon = QIcon::fromTheme(ic);
 }
 
 LogLevel::~LogLevel()
@@ -61,17 +57,12 @@ QString LogLevel::name() const
     return d->name;
 }
 
-QString LogLevel::icon() const
-{
-    return d->icon;
-}
-
 QColor LogLevel::color() const
 {
     return d->color;
 }
 
-QPixmap LogLevel::pixmap() const
+QIcon LogLevel::icon() const
 {
-    return d->pixmap;
+    return d->icon;
 }
