@@ -26,7 +26,6 @@
 
 #include <KLocalizedString>
 
-#include "logFile.h"
 #include "logLevel.h"
 
 #include "globals.h"
@@ -212,12 +211,11 @@ LogFile LogModeConfiguration::findGenericLogFile(const QString &file)
 {
     LogLevel *level = Globals::instance().informationLogLevel();
 
-    QUrl url(file);
+    QUrl url = QUrl::fromLocalFile(file);
     if (!url.isValid()) {
         logWarning() << i18n("URL '%1' is not valid, skipping this URL.", url.path());
         return LogFile(QUrl(), Globals::instance().noLogLevel());
     }
-
     return LogFile(url, level);
 }
 
@@ -240,7 +238,7 @@ QList<LogFile> LogModeConfiguration::findNoModeLogFiles(const QStringList &strin
     LogLevel *level = Globals::instance().noLogLevel();
 
     foreach (const QString &string, stringList) {
-        QUrl url(string);
+        QUrl url = QUrl::fromLocalFile(string);
         if (!url.isValid()) {
             logWarning() << i18n("URL '%1' is not valid, skipping this URL.", url.path());
             continue;
