@@ -35,8 +35,7 @@
 #include <QMetaEnum>
 #include <QStandardItemModel>
 
-#include <kcombobox.h>
-#include <kiconloader.h>
+#include <KComboBox>
 #include <KLocalizedString>
 
 class ComboBoxDelegate : public QStyledItemDelegate
@@ -134,7 +133,7 @@ LogViewFilterWidget::LogViewFilterWidget()
     d->filterLine->setPlaceholderText(i18n("Enter your search here..."));
 
     QLabel *filterIcon = new QLabel();
-    filterIcon->setPixmap(QIcon::fromTheme(QStringLiteral("view-filter")).pixmap(KIconLoader::SizeSmall));
+    filterIcon->setPixmap(QIcon::fromTheme(QStringLiteral("view-filter")).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize)));
     filterIcon->setBuddy(d->filterLine);
     filterBarLayout->addWidget(filterIcon);
 
