@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _APACHE_ACCESS_ITEM_BUILDER_H_
-#define _APACHE_ACCESS_ITEM_BUILDER_H_
+#ifndef APACHE_ACCESS_ITEM_BUILDER_H
+#define APACHE_ACCESS_ITEM_BUILDER_H
 
 #include <QString>
 
@@ -39,9 +39,9 @@ class ApacheAccessItemBuilder : public LogModeItemBuilder
 public:
     ApacheAccessItemBuilder() {}
 
-    virtual ~ApacheAccessItemBuilder() {}
+    ~ApacheAccessItemBuilder() override {}
 
-    QString createFormattedText(LogLine *line) const Q_DECL_OVERRIDE
+    QString createFormattedText(LogLine *line) const override
     {
         QString result;
 
@@ -65,4 +65,4 @@ public:
     }
 };
 
-#endif // _APACHE_ACCESS_ITEM_BUILDER_H_
+#endif // _APACHE_ACCESS_ITEM_BUILDER_H
