@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _CRON_ANALYZER_H_
-#define _CRON_ANALYZER_H_
+#ifndef CRON_ANALYZER_H
+#define CRON_ANALYZER_H
 
 #include <KLocalizedString>
 
@@ -36,14 +36,14 @@ class CronAnalyzer : public SyslogAnalyzer
     Q_OBJECT
 
 public:
-    CronAnalyzer(LogMode *logMode)
+    explicit CronAnalyzer(LogMode *logMode)
         : SyslogAnalyzer(logMode)
     {
     }
 
     virtual ~CronAnalyzer() {}
 
-    LogViewColumns initColumns() Q_DECL_OVERRIDE
+    LogViewColumns initColumns() override
     {
         LogViewColumns columns;
         columns.addColumn(LogViewColumn(i18n("Date"), true, false));
@@ -54,7 +54,7 @@ public:
         return columns;
     }
 
-    Analyzer::LogFileSortMode logFileSortMode() Q_DECL_OVERRIDE { return Analyzer::FilteredLogFile; }
+    Analyzer::LogFileSortMode logFileSortMode() override { return Analyzer::FilteredLogFile; }
 
     /*
      * Cron line example :
@@ -64,7 +64,7 @@ public:
      * Sep 16 18:39:05 localhost /usr/sbin/cron[5480]: (CRON) INFO (Running @reboot jobs)
      *
      */
-    LogLine *parseMessage(const QString &logLine, const LogFile &originalFile) Q_DECL_OVERRIDE
+    LogLine *parseMessage(const QString &logLine, const LogFile &originalFile) override
     {
         // Use the default parsing
         LogLine *syslogLine = SyslogAnalyzer::parseMessage(logLine, originalFile);
@@ -73,7 +73,7 @@ public:
 
         if (isCronLine(syslogLine) == false) {
             delete syslogLine;
-            return NULL;
+            return nullptr;
         }
 
         // Gets the message column (last item) and deletes it
