@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _CUPS_LOG_MODE_FACTORY_H_
-#define _CUPS_LOG_MODE_FACTORY_H_
+#ifndef LOG_MODE_CUPS_FACTORY_H
+#define LOG_MODE_CUPS_FACTORY_H
 
 #include <QList>
 
@@ -31,9 +31,9 @@ class CupsLogModeFactory : public LogModeFactory
     Q_OBJECT
 
 public:
-    QList<LogMode *> createLogModes() const Q_DECL_OVERRIDE;
+    QList<LogMode *> createLogModes() const override;
 
-    LogModeAction *createLogModeAction() const Q_DECL_OVERRIDE;
+    LogModeAction *createLogModeAction() const override;
 };
 
-#endif // _CUPS_LOG_MODE_FACTORY_H_
+#endif // _LOG_MODE_CUPS_FACTORY_H
