@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _CUPS_PAGE_ITEM_BUILDER_H_
-#define _CUPS_PAGE_ITEM_BUILDER_H_
+#ifndef CUPS_PAGE_ITEM_BUILDER_H
+#define CUPS_PAGE_ITEM_BUILDER_H
 
 #include <QString>
 
@@ -41,7 +41,7 @@ public:
 
     virtual ~CupsPageItemBuilder() {}
 
-    QString createFormattedText(LogLine *line) const Q_DECL_OVERRIDE
+    QString createFormattedText(LogLine *line) const override
     {
         QString result;
 
@@ -64,4 +64,4 @@ public:
     }
 };
 
-#endif // _CUPS_PAGE_ITEM_BUILDER_H_
+#endif // _CUPS_PAGE_ITEM_BUILDER_H
