@@ -22,12 +22,10 @@
 #include "cupsPdfLogMode.h"
 
 #include <QAction>
-#include <QList>
 
 #include <KLocalizedString>
 
 #include "logging.h"
-#include "logMode.h"
 
 #include "cupsPdfAnalyzer.h"
 #include "cupsPdfItemBuilder.h"
