@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _DAEMON_CONFIGURATION_WIDGET_H_
-#define _DAEMON_CONFIGURATION_WIDGET_H_
+#ifndef DAEMON_CONFIGURATION_WIDGET_H
+#define DAEMON_CONFIGURATION_WIDGET_H
 
 #include <KLocalizedString>
 
@@ -46,8 +46,7 @@ public:
         : LogModeConfigurationWidget(i18n("Daemons' Logs"), QStringLiteral(DAEMON_MODE_ICON),
                                      i18n("Daemons' Logs"))
     {
-        QHBoxLayout *layout = new QHBoxLayout();
-        this->setLayout(layout);
+        QHBoxLayout *layout = new QHBoxLayout(this);
 
         fileList = new FileList(
             this, i18n("<p>These files will be analyzed to show the <b>Daemons' Logs</b>.</p>"));
@@ -57,9 +56,9 @@ public:
 
     ~DaemonConfigurationWidget() {}
 
-public slots:
+public Q_SLOTS:
 
-    void saveConfig() Q_DECL_OVERRIDE
+    void saveConfig() override
     {
         DaemonConfiguration *daemonConfiguration = Globals::instance()
                                                        .findLogMode(QStringLiteral(DAEMON_LOG_MODE_ID))
@@ -68,7 +67,7 @@ public slots:
         daemonConfiguration->setDaemonPaths(fileList->paths());
     }
 
-    void readConfig() Q_DECL_OVERRIDE
+    void readConfig() override
     {
         DaemonConfiguration *daemonConfiguration = Globals::instance()
                                                        .findLogMode(QStringLiteral(DAEMON_LOG_MODE_ID))
@@ -79,14 +78,14 @@ public slots:
         fileList->addPaths(daemonConfiguration->daemonPaths());
     }
 
-    void defaultConfig() Q_DECL_OVERRIDE
+    void defaultConfig() override
     {
         // TODO Find a way to read the configuration per default
         readConfig();
     }
 
 protected:
-    bool isValid() const Q_DECL_OVERRIDE
+    bool isValid() const override
     {
         if (fileList->isEmpty() == false) {
             return true;
@@ -99,4 +98,4 @@ private:
     FileList *fileList;
 };
 
-#endif // _DAEMON_CONFIGURATION_WIDGET_H_
+#endif // _DAEMON_CONFIGURATION_WIDGET_H
