@@ -31,7 +31,7 @@
 /**
  * Journald Log Icon
  */
-#define JOURNALD_MODE_ICON "computer"
+#define JOURNALD_MODE_ICON "preferences-system-startup"
 
 #include <QList>
 
@@ -51,11 +51,9 @@ class JournaldLogMode : public LogMode
 public:
     explicit JournaldLogMode();
 
-    ~JournaldLogMode();
+    Analyzer *createAnalyzer(const QVariant &analyzerOptions = QVariant()) override;
 
-    Analyzer *createAnalyzer(const QVariant &analyzerOptions = QVariant());
-
-    QList<LogFile> createLogFiles();
+    QList<LogFile> createLogFiles() override;
 
     void updateJournalFilters(const JournalAddress &address, const JournalFilters &filters);
     JournalFilters filters(const JournalAddress &address) const;
