@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _SYSTEM_CONFIGURATION_WIDGET_H_
-#define _SYSTEM_CONFIGURATION_WIDGET_H_
+#ifndef SYSTEM_CONFIGURATION_WIDGET_H
+#define SYSTEM_CONFIGURATION_WIDGET_H
 
 #include "logModeConfigurationWidget.h"
 
@@ -47,8 +47,7 @@ public:
     SystemConfigurationWidget()
         : LogModeConfigurationWidget(i18n("System Log"), QStringLiteral(SYSTEM_MODE_ICON), i18n("System Log"))
     {
-        QVBoxLayout *layout = new QVBoxLayout();
-        this->setLayout(layout);
+        QVBoxLayout *layout = new QVBoxLayout(this);
 
         QString description = i18n("<p>These files will be analyzed to show the <b>System logs</b>.</p>");
 
@@ -59,9 +58,9 @@ public:
         layout->addWidget(fileList);
     }
 
-    virtual ~SystemConfigurationWidget() {}
+    ~SystemConfigurationWidget() override {}
 
-    bool isValid() const Q_DECL_OVERRIDE
+    bool isValid() const override
     {
         if (fileList->isEmpty() == false) {
             logDebug() << "System configuration valid";
@@ -72,7 +71,7 @@ public:
         return false;
     }
 
-    void saveConfig() Q_DECL_OVERRIDE
+    void saveConfig() override
     {
         logDebug() << "Saving config from System Options...";
 
@@ -83,7 +82,7 @@ public:
         systemConfiguration->setLogFilesLevels(fileList->levels());
     }
 
-    void readConfig() Q_DECL_OVERRIDE
+    void readConfig() override
     {
         SystemConfiguration *systemConfiguration = Globals::instance()
                                                        .findLogMode(QStringLiteral(SYSTEM_LOG_MODE_ID))
@@ -94,7 +93,7 @@ public:
         fileList->addPaths(systemConfiguration->logFilesPaths(), systemConfiguration->logFilesLevels());
     }
 
-    void defaultConfig() Q_DECL_OVERRIDE
+    void defaultConfig() override
     {
         // TODO Find a way to read the configuration per default
         readConfig();
@@ -104,4 +103,4 @@ private:
     LogLevelFileList *fileList;
 };
 
-#endif // _SYSTEM_CONFIGURATION_WIDGET_H_
+#endif // _SYSTEM_CONFIGURATION_WIDGET_H
