@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _XORG_CONFIGURATION_WIDGET_H_
-#define _XORG_CONFIGURATION_WIDGET_H_
+#ifndef XORG_CONFIGURATION_WIDGET_H
+#define XORG_CONFIGURATION_WIDGET_H
 
 #include <KLocalizedString>
 
@@ -44,8 +44,7 @@ public:
     XorgConfigurationWidget()
         : LogModeConfigurationWidget(i18n("X.org Log"), QStringLiteral(XORG_MODE_ICON), i18n("X.org Log"))
     {
-        QHBoxLayout *layout = new QHBoxLayout();
-        this->setLayout(layout);
+        QHBoxLayout *layout = new QHBoxLayout(this);
 
         fileList
             = new FileList(this, i18n("<p>These files will be analyzed to show the <b>X.org log</b>.</p>"));
@@ -53,11 +52,11 @@ public:
         layout->addWidget(fileList);
     }
 
-    ~XorgConfigurationWidget() {}
+    ~XorgConfigurationWidget() override {}
 
-public slots:
+public Q_SLOTS:
 
-    void saveConfig() Q_DECL_OVERRIDE
+    void saveConfig() override
     {
         XorgConfiguration *xorgConfiguration = Globals::instance()
                                                    .findLogMode(QStringLiteral(XORG_LOG_MODE_ID))
@@ -66,7 +65,7 @@ public slots:
         xorgConfiguration->setXorgPaths(fileList->paths());
     }
 
-    void readConfig() Q_DECL_OVERRIDE
+    void readConfig() override
     {
         XorgConfiguration *xorgConfiguration = Globals::instance()
                                                    .findLogMode(QStringLiteral(XORG_LOG_MODE_ID))
@@ -77,14 +76,14 @@ public slots:
         fileList->addPaths(xorgConfiguration->xorgPaths());
     }
 
-    void defaultConfig() Q_DECL_OVERRIDE
+    void defaultConfig() override
     {
         // TODO Find a way to read the configuration per default
         readConfig();
     }
 
 protected:
-    bool isValid() const Q_DECL_OVERRIDE
+    bool isValid() const override
     {
         if (fileList->isEmpty() == false) {
             return true;
@@ -97,4 +96,4 @@ private:
     FileList *fileList;
 };
 
-#endif // _XORG_CONFIGURATION_WIDGET_H_
+#endif // _XORG_CONFIGURATION_WIDGET_H
