@@ -21,12 +21,10 @@
 
 #include "xsessionLogMode.h"
 
-#include <QList>
 
 #include <KLocalizedString>
 
 #include "logging.h"
-#include "logMode.h"
 
 #include "xsessionAnalyzer.h"
 #include "xsessionItemBuilder.h"
