@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _TAB_LOG_VIEWS_WIDGET_H_
-#define _TAB_LOG_VIEWS_WIDGET_H_
+#ifndef TAB_LOG_VIEWS_WIDGET_H
+#define TAB_LOG_VIEWS_WIDGET_H
 
 #include <QTabWidget>
 #include <QList>
@@ -41,7 +41,7 @@ class TabLogViewsWidget : public QTabWidget
     Q_OBJECT
 
 public:
-    TabLogViewsWidget(QWidget *parent = NULL);
+    explicit TabLogViewsWidget(QWidget *parent = nullptr);
 
     virtual ~TabLogViewsWidget();
 
@@ -51,7 +51,7 @@ public:
 
     void load(LogMode *logMode, LogManager *manager, const QVariant &analyzerOptions = QVariant());
 
-public slots:
+public Q_SLOTS:
 
     LogManager *createTab();
     LogManager *duplicateTab();
@@ -79,7 +79,7 @@ public slots:
     void sendMailCurrentView();
     void printSelectionCurrentView();
 
-private slots:
+private Q_SLOTS:
     void changeTab(View *view, const QIcon &icon, const QString &label);
 
     void changeCurrentTab(int index);
@@ -88,7 +88,7 @@ private slots:
     void showContextMenu(const QPoint &cursorPosition);
     void showContextMenu(QWidget *tab, const QPoint &cursorPosition);
 
-signals:
+Q_SIGNALS:
     void tabCreationRequested();
     void tabClosingRequested();
 
@@ -113,4 +113,4 @@ private:
     TabLogViewsWidgetPrivate *const d;
 };
 
-#endif // _TAB_LOG_VIEWS_WIDGET_H_
+#endif // _TAB_LOG_VIEWS_WIDGET_H
